\name{morepoints}
\alias{morepoints}
\title{Create new design points similar to those supplied}
\usage{
morepoints(X, keep, n, fac = 10)
}
\arguments{
  \item{X}{design matrix}

  \item{keep}{Subscript showing which rows of \code{X} to
  match with the new points}

  \item{n}{Number of additional points required}

  \item{fac}{Expansion factor for over-sampling, see
  Details}
}
\value{
A new design matrix with \code{n} rows.  If \code{X} has
class \code{boxdesign}, then so does the new design.
}
\description{
Take a set of points, and generate additional points that
are close to an identified subset of them.
}
\details{
This is a stochastic method which generates new points in
the same hyper-rectangle as \code{X}, and then keeps the
best \code{n}, according to the following rules:

\enumerate{

\item Only points that are nearer to a point in
\code{X[keep, ]} than they are to a point in \code{X[-keep,
]} are retained.

\item If fewer than \code{n} points are retained, then the
function iterates until there are at least \code{n} points.

\item If there are more than \code{n} points retained, then
each point \code{z} is ranked in terms of its distance to
the nearest point in the union of \code{X[keep, ]} and
\code{Z[-z, ]}, and the \code{n} points with the largest
distances are retained. }

\eqn{fac * n} points are generated in each iteration.  Try
increasing \code{fac} if the function seems slow.

All interpoint distances are computed after
standardisation. \code{morepoints} has special handling for
design matrices of class \code{boxdesign}, for which the
lower and upper limits are available as an attribute.
}
\examples{
X <- lhcube(101, 2); colnames(X) <- c("x", "y")
z <- apply(X, 1, banana, theta = 100)
plot(X, col = 1 + (z > 10), pch = 20)
moreX <- morepoints(X, keep = z > 10, n = 51)
points(moreX, col = "blue", pch = 20)
}
\seealso{
\code{\link{lhcube}} for generating space-filling designs
in the unit cube, and \code{\link{boxdesign}} for simple
rectangular designs.
}

