\name{parcoord}
\alias{parcoord}
\title{Produce a parallel coordinates plot.}
\usage{
parcoord(data, lower = NULL, upper = NULL, log = NULL, col = 1,
  lty = 1, lwd = 1, plotorder = NULL, var.label = FALSE,
  col.axis = "darkgrey", at = 1L:p)
}
\arguments{
  \item{data}{matrix or data frame}

  \item{lower,upper}{lower and upper bounds for each axis
  (see Details)}

  \item{log}{Names of variables to have log scales}

  \item{col}{colour for rows of \code{data}}

  \item{lty}{line type for rows of \code{data}}

  \item{lwd}{line width for rows of \code{data}}

  \item{plotorder}{overplotting ordering of lines}

  \item{var.label}{provide lower and upper values for the
  axes?}

  \item{col.axis}{colour of the axes}

  \item{at}{relative position of the axes}
}
\description{
A parallel coordinates plot is a simple way to viualise
multivariate data, using one vertical axis for each
variable, and a line across the axes for each case.  The
lines can be distinguished by colour or by line type to
show subgroups.
}
\details{
This is a slightly more elegant version of \code{parcoord}
in the \code{MASS} package.  Variables with no variability
are dropped with a warning.

If \code{lwd} is supplied, then the thicker lines are
plotted on top of the thinner ones.

Use \code{par("cex.lab")} to change the scaling of the axis
labels and the axis values.  It may also be necessary to
increase the first component of \code{par("mar")} to show
the variable names.

Use \code{lower} and \code{upper} to include \code{ylim}
values for the axis of each variable.  If not \code{NULL}
these must be appropriate to \code{rbind} with \code{data}.
An \code{NA} in \code{lower} or \code{upper} indicates a
data-determined limit. See Examples.
}
\examples{
op <- par(no.readonly = TRUE)
par(mar = c(5, 1, 1, 1), cex.lab = 0.7)
parcoord(iris[, 1:4], col = iris$Species, var.label = TRUE)

## example with ylim values (can also include NAs)

parcoord(iris[, 1:4], lower = 0, upper = 10, col = iris$Species, var.label = TRUE)
legend("topright", legend = levels(iris$Species), col = 1:3, lty = 1, pch = NA)

## with NA's

parcoord(iris[, 1:4], lower = c(NA, NA, 0, 0), upper = 10, col = iris$Species, var.label = TRUE)
par(op)
}
\seealso{
\code{parcoord} in the \code{MASS} package
}
\keyword{graphics}

