\name{prvar}
\alias{prvar}
\title{Principal variables}
\usage{
prvar(X, as.names = FALSE)
}
\arguments{
  \item{X}{Matrix or dataframe, must be numeric}

  \item{as.names}{Return ordering as names or indices?}
}
\value{
A vector of names or indices, with a \code{scree} attribute
containing a vector of scree values (like a scree plot in
principal components)
}
\description{
Identify the principal variables in a matrix or dataframe.
}
\details{
I apply the Cumming and Wooff (2007) algorithm to the
maximal linearly independent set of columns of \code{X},
which is found using the \code{\link{ref}} function.
}
\examples{
pv <- prvar(state.x77, as.names = TRUE)
scree <- attr(pv, "scree")
plot(scree, ylim = c(0, 1), pch = 20,
  xlab = "", ylab = "Proportion of variation",
  main = "Principal variables scree plot",
  axes = FALSE, bty = "n")
axis(1, seq(along = scree), names(scree), las = 2, pos = 0, tick = FALSE)
axis(2)
abline(h = c(0, 1), col = "darkgrey")
}
\references{
J.A. Cumming and D.A. Wooff, 2007, Dimension reduction via
principal variables, Computational Statistics and Data
Analysis, 52, 560-565.
}

